@@ -44,16 +44,21 @@ from time import sleep
 import mozrunner
 import simplesettings
 
-from network import create_network
+import network
 from jsobjects import JSObject
 import global_settings
 
 settings_env = 'JSBRIDGE_SETTINGS_FILE'
 
-def start_js_bridge(hostname='127.0.0.1', port=4242):
-    back_channel, repl = create_network(hostname, port)
-    bridge = JSObject(repl, "Components.classes['@mozilla.org/appshell/window-mediator;1'].getService(Components.interfaces.nsIWindowMediator).getMostRecentWindow('')")
-    return back_channel, repl, bridge
+back_channel = None
+
+def getBrowserWindow():
+    return JSObject(network.bridge, "Components.classes['@mozilla.org/appshell/window-mediator;1'].getService(Components.interfaces.nsIWindowMediator).getMostRecentWindow('')")
+    
+def getPreferencesWindow():
+    bridge = JSObject(network.bridge, "openPreferences()")
+    sleep(1)
+    return bridge
     
 def ipython_shell(locals_dict):
     from IPython.Shell import IPShellEmbed
@@ -90,7 +95,32 @@ def start_from_settings(settings, timeout=10):
             settings['JSBRIDGE_REPL_HOST'] =  'localhost:4242'
         host, port = settings['JSBRIDGE_REPL_HOST'].split(':')
         port = int(port)
-    return start_js_bridge(host, port)
+    
+    network.create_network(host, port)
+    browser_window = JSObject(network.bridge, "Components.classes['@mozilla.org/appshell/window-mediator;1'].getService(Components.interfaces.nsIWindowMediator).getMostRecentWindow('')")
+    return browser_window
+
+
+def set_debug(settings):
+    
+    module_path = global_settings.module_path   
+    settings['MOZILLA_PLUGINS'] += [os.path.join(module_path, 'xpi',
+                                        'javascript_debugger-0.9.87.4-fx+tb+sb+sm.xpi'),
+                                    os.path.join(module_path, 'xpi', 'firebug-1.2.0b7-fx.xpi'),
+                                    os.path.join(module_path, 'xpi', 'chromebug-trunk'),
+                                    ]
+    settings['MOZILLA_CMD_ARGS'] += ['-jsconsole', '-chrome', 
+                                     'chrome://chromebug/content/chromebug.xul', 
+                                     '-p', 'chromebug', '-firefox']
+    rdf = open(os.path.join(module_path, 'xpi', 'chromebug-trunk', 'install.rdf.tpl.xml'), 'r').read()
+    rdf = rdf.replace('@FULLVERSION@', '0.1')
+    rdf = rdf.replace('<em:updateURL>@UPDATEPATH@/update.rdf</em:updateURL>\n', '')
+    rdf = rdf.replace('<em:homepageURL>@UPDATEPATH@/index.html</em:homepageURL>\n', '')
+    rdf = rdf.replace('<em:updateKey>ToBeReplaceByAValueFromMcCoy</em:updateKey>\n', '')
+    f = open(os.path.join(module_path, 'xpi', 'chromebug-trunk', 'install.rdf'), 'w')
+    f.write(rdf)
+    f.close()
+    return settings
     
 def main():
     parser = optparse.OptionParser()
@@ -104,6 +134,11 @@ def main():
                       help="Launch a new firefox instance.", metavar=None)
     parser.add_option('-u', "--host", dest='host', 
                       help="The hostname:port pairing to connect to mozrepl.")
+                      
+    parser.add_option("-z", "--debug",
+                      action="store_true", dest="debug", default=False,
+                      help="Run with firebug, chromebug, venkman, and jsconsole")
+    
     (options, args) = parser.parse_args()
     
     settings_path = getattr(options, 'settings', None)
@@ -124,21 +159,30 @@ def main():
     for opt, override in option_overrides:
         if getattr(options, opt, None) is not None:
             settings[override] = getattr(options, opt)
+    
+    if options.debug is True:
+        set_debug(settings)    
         
-    back_channel, repl, bridge = start_from_settings(settings)
+    bridge = start_from_settings(settings)
     if settings.has_key('moz'):
         # We want the moz object in the local ns or the shell to access
         moz = settings['moz']
-        
-    if sys.platform != 'win32':
-        sys.argv = sys.argv[:1]
-        ipython_shell({'bridge':bridge})#locals())
-    else:
-        code_shell({'bridge':bridge})
     
-    # There is a bug in some of the traceback code IPython keeps around that causes a strange error here.
-    # The workaround is to remove it from sys.modules
-    sys.modules.pop('IPython', None)
+    try:
+        import IPython
+    except:
+        IPython = None    
+    if IPython is not None and '--usecode' not in sys.argv:
+        sys.argv = sys.argv[:1]
+        ipython_shell({'bridge':bridge, 'getBrowserWindow':getBrowserWindow, 'getPreferencesWindow':getPreferencesWindow})#locals())
+    else:
+        code_shell({'bridge':bridge, 'getBrowserWindow':getBrowserWindow, 'getPreferencesWindow':getPreferencesWindow})
+    
+    # # There is a bug in some of the traceback code IPython keeps around that causes a strange error here.
+    # # The workaround is to remove it from sys.modules
+    # x = sys.modules.pop('IPython', None)
+    # if x is not None:
+    #     del x
     
     if settings.has_key('moz'):
         moz.stop()
